@@ -80,11 +80,11 @@ class NodeTemplate(Node):
         except FileNotFoundError:
             pass
 
-    def sub_process(self, ctx=None, sep=""):
+    def sub_process(self, ctx=None, ):
         if ctx is None:
             ctx = Context()
 
-        def wrapped(node: Node):
+        def wrapped(node: Node, sep=""):
             if type(node) == list:
                 nodes = map(lambda e: e.process(ctx), node)
                 return sep.join(nodes)
